@@ -1,14 +1,14 @@
 import asyncio
-import io
 from typing import Any, Awaitable, Callable, Literal, MutableMapping, Tuple
 
 from aiohttp import web
 from aiohttp.http_parser import RawRequestMessage
+from aiohttp.streams import StreamReader
 from aiohttp.payload import StringPayload
 from multidict import CIMultiDict, CIMultiDictProxy
 from yarl import URL
 
-from .api import Api
+from .server import APIServer
 
 Scope = MutableMapping[str, Any]
 Message = MutableMapping[str, Any]
@@ -18,7 +18,7 @@ Send = Callable[[Message], Awaitable[None]]
 ASGIApp = Callable[[Scope, Receive, Send], Awaitable[None]]
 
 
-class ASGIApi(Api):
+class ASGIServer(APIServer):
     """
     An ASGI-compatible API.
 
@@ -26,8 +26,7 @@ class ASGIApi(Api):
 
     Tested with:
     `uvicorn`
-    `daphne`[TODO]
-
+    `mangum`
     """
 
     async def asgi(self, scope: Scope, _, send: Send) -> None:
@@ -69,7 +68,7 @@ class ASGIApi(Api):
 
         request = web.Request(
             message=message,
-            payload=io.BytesIO(),
+            payload=StreamReader(protocol=_proto,limit=2**20),
             protocol=_proto,
             payload_writer=None,
             task=None,
@@ -98,4 +97,4 @@ class ASGIApi(Api):
 
     async def __call__(self, scope: Scope, receive: Receive, send: Send) -> None:
         """ASGI callable."""
-        return await self.asgi(scope, receive, send)
+        return await self.asgi(scope, receive, send)
\ No newline at end of file
